Practice
-----------------------------------------------------

Please try to solve each of the following problems. Do not use any outside
resources.

Practice Problems
=====================

.. selectquestion:: class-test-sq1
   :ab: class-test-dist-and-no
   :fromid: Classes_Basic_Airport_pp, Classes_Basic_Airport-nd_pp
   :points: 10

.. selectquestion:: class-test-sq2
   :ab: class-test-dist-and-no
   :fromid: Classes_Basic_Song_pp, Classes_Basic_Song_nd_pp
   :points: 10

.. selectquestion:: class-test-sq3
   :ab: class-test-dist-and-no
   :fromid: Classes_Basic_Cat_pp, Classes_Basic_Cat_nd_pp
   :points: 10

.. selectquestion:: class-test-sq4
   :ab: class-test-dist-and-no
   :fromid: Classes_Basic_Account_pp, Classes_Basic_Account_nd_pp
   :points: 10

.. selectquestion:: class-dist-test-sq5
   :ab: class-test-dist-and-no
   :fromid: Classes_Basic_FortuneTeller_pp, Classes_Basic_FortuneTeller_nd_pp
   :points: 10

Feedback
==================================

.. shortanswer:: iwgex1-p3-ex-sa

   Please provide feedback here. Please share any comments, problems, or suggestions.

What to do next
============================

Click on the following link: `Post Test <p3-post.html>`_
